@@ -154,6 +154,13 @@ class Starter(FS):
             t.name for t in templates)
         logging.warning("Paste templates: {0}".format(tt))
         self.make_directory(self.params.TARGET)
+
+        logging.debug("\nDefault context:\n----------------")
+        logging.debug(
+            ''.join('{0:<15} {1}\n'.format(*v)
+            for v in sorted(self.parser.default.items()))
+        )
+
         return [t.paste(**self.parser.default) for t in templates]
 
     def prepare_templates(self):
